@@ -28,9 +28,9 @@ __doc__ = __doc__.format("\n   ".join(__all__))
 
 import datetime as dt
 import io
-from distutils.version import LooseVersion
 
 import numpy as np
+from packaging.version import Version
 from xarray import Dataset
 from xarray.backends import NetCDF4DataStore
 from xarray.backends.common import (
@@ -111,7 +111,7 @@ class RadolanDataStore(AbstractDataStore):
                 _radolan_file,
                 filename_or_obj,
                 lock=lock,
-                kwargs=dict(fillmissing=fillmissing, copy=copy),
+                kwargs={"fillmissing": fillmissing, "copy": copy},
             )
         else:
             if isinstance(filename_or_obj, bytes):
@@ -131,7 +131,7 @@ class RadolanDataStore(AbstractDataStore):
         return self._acquire()
 
     def open_store_variable(self, name, var):
-        encoding = dict(source=self._filename)
+        encoding = {"source": self._filename}
         if isinstance(var.data, np.ndarray):
             data = var.data
         else:
@@ -393,16 +393,16 @@ class OdimStore(AbstractDataStore):
 
         kwargs = {"invalid_netcdf": invalid_netcdf}
         if phony_dims is not None:
-            if LooseVersion(h5netcdf.__version__) >= LooseVersion("0.8.0"):
+            if Version(h5netcdf.__version__) >= Version("0.8.0"):
                 kwargs["phony_dims"] = phony_dims
             else:
                 raise ValueError(
                     "h5netcdf backend keyword argument 'phony_dims' needs "
                     "h5netcdf >= 0.8.0."
                 )
-        if LooseVersion(h5netcdf.__version__) >= LooseVersion(
-            "0.10.0"
-        ) and LooseVersion(h5netcdf.core.h5py.__version__) >= LooseVersion("3.0.0"):
+        if Version(h5netcdf.__version__) >= Version("0.10.0") and Version(
+            h5netcdf.core.h5py.__version__
+        ) >= Version("3.0.0"):
             kwargs["decode_vlen_strings"] = decode_vlen_strings
 
         if lock is None:
@@ -519,6 +519,8 @@ class OdimBackendEntrypoint(BackendEntrypoint):
             decode_timedelta=decode_timedelta,
         )
 
+        ds.encoding["engine"] = "odim"
+
         if decode_coords and reindex_angle is not False:
             ds = ds.pipe(_reindex_angle, store=store, tol=reindex_angle)
 
@@ -579,16 +581,16 @@ class GamicStore(AbstractDataStore):
 
         kwargs = {"invalid_netcdf": invalid_netcdf}
         if phony_dims is not None:
-            if LooseVersion(h5netcdf.__version__) >= LooseVersion("0.8.0"):
+            if Version(h5netcdf.__version__) >= Version("0.8.0"):
                 kwargs["phony_dims"] = phony_dims
             else:
                 raise ValueError(
                     "h5netcdf backend keyword argument 'phony_dims' needs "
                     "h5netcdf >= 0.8.0."
                 )
-        if LooseVersion(h5netcdf.__version__) >= LooseVersion(
-            "0.10.0"
-        ) and LooseVersion(h5netcdf.core.h5py.__version__) >= LooseVersion("3.0.0"):
+        if Version(h5netcdf.__version__) >= Version("0.10.0") and Version(
+            h5netcdf.core.h5py.__version__
+        ) >= Version("3.0.0"):
             kwargs["decode_vlen_strings"] = decode_vlen_strings
 
         if lock is None:
@@ -699,6 +701,8 @@ class GamicBackendEntrypoint(BackendEntrypoint):
             decode_timedelta=decode_timedelta,
         )
 
+        ds.encoding["engine"] = "gamic"
+
         ds = ds.sortby(list(ds.dims.keys())[0])
 
         if decode_coords and reindex_angle is not False:
@@ -923,7 +927,7 @@ class IrisStore(AbstractDataStore):
         dim = self.root.first_dimension
 
         data = indexing.LazilyOuterIndexedArray(IrisArrayWrapper(self, name, var))
-        encoding = dict(group=self._group)
+        encoding = {"group": self._group}
 
         mname = iris_mapping.get(name, name)
         mapping = moments_mapping.get(mname, {})
@@ -952,7 +956,7 @@ class IrisStore(AbstractDataStore):
         time = (
             var["sweep_start_time"] - dt.datetime(1970, 1, 1, tzinfo=dt.timezone.utc)
         ).total_seconds()
-        encoding = dict(group=self._group)
+        encoding = {"group": self._group}
         rtime_attrs = {
             "units": f"{time_prefix}seconds since {var['sweep_start_time'].replace(tzinfo=None).isoformat()}Z",
             "standard_name": "time",
@@ -961,16 +965,22 @@ class IrisStore(AbstractDataStore):
 
         # get coordinates from IrisFile
         sweep_mode = "azimuth_surveillance" if dim == "azimuth" else "rhi"
-        lon_attrs = dict(
-            long_name="longitude", units="degrees_east", standard_name="longitude"
-        )
-        lat_attrs = dict(
-            long_name="latitude",
-            units="degrees_north",
-            positive="up",
-            standard_name="latitude",
-        )
-        alt_attrs = dict(long_name="altitude", units="meters", standard_name="altitude")
+        lon_attrs = {
+            "long_name": "longitude",
+            "units": "degrees_east",
+            "standard_name": "longitude",
+        }
+        lat_attrs = {
+            "long_name": "latitude",
+            "units": "degrees_north",
+            "positive": "up",
+            "standard_name": "latitude",
+        }
+        alt_attrs = {
+            "long_name": "altitude",
+            "units": "meters",
+            "standard_name": "altitude",
+        }
         lon, lat, alt = self.root.site_coords
 
         task = self.root.ingest_header["task_configuration"]["task_range_info"]
@@ -993,17 +1003,17 @@ class IrisStore(AbstractDataStore):
 
         rtime = Variable((dim,), rtime, rtime_attrs, encoding)
 
-        coords = dict(
-            azimuth=Variable((dim,), azimuth, az_attrs, encoding),
-            elevation=Variable((dim,), elevation, el_attrs, encoding),
-            rtime=rtime,
-            time=Variable((), time, time_attrs, encoding),
-            range=Variable(("range",), range, range_attrs),
-            longitude=Variable((), lon, lon_attrs),
-            latitude=Variable((), lat, lat_attrs),
-            altitude=Variable((), alt, alt_attrs),
-            sweep_mode=Variable((), sweep_mode),
-        )
+        coords = {
+            "azimuth": Variable((dim,), azimuth, az_attrs, encoding),
+            "elevation": Variable((dim,), elevation, el_attrs, encoding),
+            "rtime": rtime,
+            "time": Variable((), time, time_attrs, encoding),
+            "range": Variable(("range",), range, range_attrs),
+            "longitude": Variable((), lon, lon_attrs),
+            "latitude": Variable((), lat, lat_attrs),
+            "altitude": Variable((), alt, alt_attrs),
+            "sweep_mode": Variable((), sweep_mode),
+        }
 
         # a1gate
         a1gate = np.where(rtime.values == rtime.values.min())[0][0]
@@ -1034,9 +1044,7 @@ class IrisStore(AbstractDataStore):
         ing_head = self.ds["ingest_data_hdrs"]
         data = ing_head[list(ing_head.keys())[0]]
 
-        attributes = dict(
-            fixed_angle=np.round(data["fixed_angle"], 1),
-        )
+        attributes = {"fixed_angle": np.round(data["fixed_angle"], 1)}
         # RHI limits
         if self.root.scan_mode == 2:
             tsi = self.root.ingest_header["task_configuration"]["task_scan_info"][
@@ -1045,15 +1053,14 @@ class IrisStore(AbstractDataStore):
             ll = tsi["lower_elevation_limit"]
             ul = tsi["upper_elevation_limit"]
             attributes.update(
-                dict(
-                    elevation_lower_limit=ll,
-                    elevation_upper_limit=ul,
-                )
+                {"elevation_lower_limit": ll, "elevation_upper_limit": ul}
             )
         return FrozenDict(attributes)
 
 
 class IrisBackendEntrypoint(BackendEntrypoint):
+    """Xarray BackendEntrypoint for IRIS/Sigmet data."""
+
     def open_dataset(
         self,
         filename_or_obj,
@@ -1179,12 +1186,12 @@ class RainbowStore(AbstractDataStore):
         name = raw["@type"]
 
         data = indexing.LazilyOuterIndexedArray(RainbowArrayWrapper(self, name, raw))
-        encoding = dict(group=self._group)
+        encoding = {"group": self._group}
 
         vmin = float(raw.get("@min"))
         vmax = float(raw.get("@max"))
         depth = int(raw.get("@depth"))
-        scale_factor = (vmax - vmin) / (2 ** depth - 2)
+        scale_factor = (vmax - vmin) / (2**depth - 2)
         mname = rainbow_mapping.get(name, name)
         mapping = moments_mapping.get(mname, {})
         attrs = {key: mapping[key] for key in moment_attrs if key in mapping}
@@ -1214,7 +1221,7 @@ class RainbowStore(AbstractDataStore):
             var, "antdirection", default=0, dtype=bool
         )
 
-        encoding = dict(group=self._group)
+        encoding = {"group": self._group}
         startangle = indexing.LazilyOuterIndexedArray(
             RainbowArrayWrapper(self, start_idx, start)
         )
@@ -1311,29 +1318,35 @@ class RainbowStore(AbstractDataStore):
 
         # get coordinates from RainbowFile
         sweep_mode = "azimuth_surveillance" if dim == "azimuth" else "rhi"
-        lon_attrs = dict(
-            long_name="longitude", units="degrees_east", standard_name="longitude"
-        )
-        lat_attrs = dict(
-            long_name="latitude",
-            units="degrees_north",
-            positive="up",
-            standard_name="latitude",
-        )
-        alt_attrs = dict(long_name="altitude", units="meters", standard_name="altitude")
+        lon_attrs = {
+            "long_name": "longitude",
+            "units": "degrees_east",
+            "standard_name": "longitude",
+        }
+        lat_attrs = {
+            "long_name": "latitude",
+            "units": "degrees_north",
+            "positive": "up",
+            "standard_name": "latitude",
+        }
+        alt_attrs = {
+            "long_name": "altitude",
+            "units": "meters",
+            "standard_name": "altitude",
+        }
         lon, lat, alt = self.root.site_coords
 
-        coords = dict(
-            azimuth=azimuth,
-            elevation=elevation,
-            range=rng,
-            time=time,
-            rtime=rtime,
-            longitude=Variable((), lon, lon_attrs),
-            latitude=Variable((), lat, lat_attrs),
-            altitude=Variable((), alt, alt_attrs),
-            sweep_mode=Variable((), sweep_mode),
-        )
+        coords = {
+            "azimuth": azimuth,
+            "elevation": elevation,
+            "range": rng,
+            "time": time,
+            "rtime": rtime,
+            "longitude": Variable((), lon, lon_attrs),
+            "latitude": Variable((), lat, lat_attrs),
+            "altitude": Variable((), alt, alt_attrs),
+            "sweep_mode": Variable((), sweep_mode),
+        }
 
         # a1gate, this might be off by 1 if reindexing is applied
         if dim == "azimuth":
@@ -1355,11 +1368,13 @@ class RainbowStore(AbstractDataStore):
         )
 
     def get_attrs(self):
-        attributes = dict(fixed_angle=float(self.ds["posangle"]))
+        attributes = {"fixed_angle": float(self.ds["posangle"])}
         return FrozenDict(attributes)
 
 
 class RainbowBackendEntrypoint(BackendEntrypoint):
+    """Xarray BackendEntrypoint for Rainbow5 data."""
+
     def open_dataset(
         self,
         filename_or_obj,
