@@ -27,9 +27,9 @@ __all__ = [
 __doc__ = __doc__.format("\n   ".join(__all__))
 
 import datetime as dt
-from distutils.version import LooseVersion
 
 import numpy as np
+from packaging.version import Version
 
 from wradlib.io.xarray import (
     open_radar_dataset,
@@ -430,7 +430,7 @@ def read_gamic_scan(scan, scan_type, wanted_moments):
             data1 = {}
             sg2 = scan[mom]
             actual_moment = sg2.attrs.get("moment")
-            if LooseVersion(h5py.__version__) < LooseVersion("3.0.0"):
+            if Version(h5py.__version__) < Version("3.0.0"):
                 actual_moment = actual_moment.decode()
             actual_moment = actual_moment.upper()
             if (actual_moment in wanted_moments) or (wanted_moments == "all"):
@@ -441,7 +441,7 @@ def read_gamic_scan(scan, scan_type, wanted_moments):
                 dyn_range_max = sg2.attrs.get("dyn_range_max")
                 dyn_range_min = sg2.attrs.get("dyn_range_min")
                 bin_format = sg2.attrs.get("format")
-                if LooseVersion(h5py.__version__) < LooseVersion("3.0.0"):
+                if Version(h5py.__version__) < Version("3.0.0"):
                     bin_format = bin_format.decode()
                 if bin_format == "UV8":
                     div = 254
@@ -520,7 +520,7 @@ def read_gamic_hdf5(filename, wanted_elevations=None, wanted_moments=None):
 
         # get scan_type (PVOL or RHI)
         scan_type = f["what"].attrs.get("object")
-        if LooseVersion(h5py.__version__) < LooseVersion("3.0.0"):
+        if Version(h5py.__version__) < Version("3.0.0"):
             scan_type = scan_type.decode()
 
         # single or volume scan
@@ -619,8 +619,7 @@ def from_hdf5(fpath, dataset="data"):
         # Check whether Dataset exists
         if dataset not in f.keys():
             raise KeyError(
-                "WRADLIB: Cannot read Dataset <%s> from hdf5 file "
-                "<%s>" % (dataset, f)
+                f"WRADLIB: Cannot read Dataset <{dataset}> from hdf5 file <{f}>"
             )
         data = np.array(f[dataset][:])
         # get metadata
@@ -724,9 +723,7 @@ def read_gpm(filename, bbox=None):
     # Determine the dimensions
     ndim = refl.ndim
     if ndim != 3:
-        raise ValueError(
-            "GPM Dimensions do not match! " "Needed 3, given {0}".format(ndim)
-        )
+        raise ValueError(f"GPM Dimensions do not match! Needed 3, given {ndim}")
 
     tmp = refl.shape
     nscan = tmp[0]
@@ -882,9 +879,7 @@ def read_trmm(filename1, filename2, bbox=None):
     # Determine the dimensions
     ndim = refl.ndim
     if ndim != 3:
-        raise ValueError(
-            "TRMM Dimensions do not match!" "Needed 3, given {0}".format(ndim)
-        )
+        raise ValueError(f"TRMM Dimensions do not match! Needed 3, given {ndim}")
 
     tmp = refl.shape
     nscan = tmp[0]
