@@ -251,8 +251,8 @@ def read_dx(filename):
 
     azimuthbitmask = 2 ** (14 - 1)
     databitmask = 2 ** (13 - 1) - 1
-    clutterflag = 2 ** 15
-    dataflag = 2 ** 13 - 1
+    clutterflag = 2**15
+    dataflag = 2**13 - 1
 
     with get_radolan_filehandle(filename) as f:
 
@@ -640,8 +640,8 @@ def read_radolan_binary_array(fid, size, raise_on_error=True):
         except AttributeError:
             desc = repr(fid)
         raise IOError(
-            "{0}: File corruption while reading {1}! \nCould not "
-            "read enough data!".format(__name__, desc)
+            f"{__name__}: File corruption while reading {desc}! \nCould not "
+            "read enough data!"
         )
     return binarr
 
@@ -810,8 +810,11 @@ def _get_radolan_product_attributes(attrs):
         interval = attrs["intervalseconds"]
         precision = attrs["precision"]
 
-    if product in ["RX", "EX", "WX", "WN"]:
+    if product in ["RX", "EX", "WX"]:
         pattrs.update(radolan["dBZ"])
+    elif product in ["WN"]:
+        pattrs.update(radolan["dBZ2"])
+        pattrs["scale_factor"] *= np.float32(precision)
     elif product in [
         "RY",
         "RZ",
@@ -908,6 +911,16 @@ radolan = {
         "long_name": "equivalent_reflectivity_factor",
         "unit": "dBZ",
     },
+    "dBZ2": {
+        "scale_factor": np.float32(0.5),
+        "add_offset": np.float32(-32.5),
+        "valid_min": np.int32(0),
+        "valid_max": np.int32(4095),
+        "_FillValue": np.array([2490, 2500, 65535], dtype=np.int32),
+        "standard_name": "equivalent_reflectivity_factor",
+        "long_name": "equivalent_reflectivity_factor",
+        "unit": "dBZ",
+    },
     "RR": {
         "add_offset": np.float32(0),
         "valid_min": np.int32(0),
@@ -943,7 +956,7 @@ radolan = {
 }
 
 
-class _radolan_file(object):
+class _radolan_file:
     """A file object for RADOLAN data.
 
     This class maps RADOLAN data to NetCDF style dimensions, variables and attributes.
@@ -1059,7 +1072,7 @@ class _radolan_file(object):
         # handle truncated data
         binarr_kwargs = {}
         if self._fill and self.product not in ["PG", "PC"]:
-            binarr_kwargs.update(dict(raise_on_error=False))
+            binarr_kwargs.update({"raise_on_error": False})
         # read data
         size = self.attrs["datasize"]
         indat = read_radolan_binary_array(self.fp, size, **binarr_kwargs)
@@ -1069,7 +1082,7 @@ class _radolan_file(object):
 
         if self.product in ["PC", "PG"]:
             self._data = decode_radolan_runlength_array(
-                indat, dict(ncol=self.attrs["ncol"], nodataflag=255)
+                indat, {"ncol": self.attrs["ncol"], "nodataflag": 255}
             )
         else:
             self._data = np.frombuffer(indat, dtype=self.dtype)
@@ -1089,12 +1102,7 @@ class _radolan_file(object):
         self.dimensions["y"] = self.attrs["nrow"]
         self.dimensions["x"] = self.attrs["ncol"]
 
-        pattrs.update(
-            dict(
-                long_name=self.product,
-                coordinates="time y x",
-            )
-        )
+        pattrs.update({"long_name": self.product, "coordinates": "time y x"})
 
         data_var = WradlibVariable(self.dimensions, data=self, attrs=pattrs)
 
@@ -1184,10 +1192,10 @@ def open_radolan_dataset(filename_or_obj, **kwargs):
     dataset : :py:class:`xarray:xarray.Dataset`
     """
     raise_on_missing_xarray_backend()
-    backend_kwargs = dict(
-        fillmissing=kwargs.pop("fillmissing", False),
-        copy=kwargs.pop("copy", False),
-    )
+    backend_kwargs = {
+        "fillmissing": kwargs.pop("fillmissing", False),
+        "copy": kwargs.pop("copy", False),
+    }
     kwargs["backend_kwargs"] = backend_kwargs
     return xr.open_dataset(filename_or_obj, engine="radolan", **kwargs)
 
@@ -1221,10 +1229,10 @@ def open_radolan_mfdataset(paths, **kwargs):
     .. [1] https://docs.dask.org/en/latest/
     """
     raise_on_missing_xarray_backend()
-    backend_kwargs = dict(
-        fillmissing=kwargs.pop("fillmissing", False),
-        copy=kwargs.pop("copy", False),
-    )
+    backend_kwargs = {
+        "fillmissing": kwargs.pop("fillmissing", False),
+        "copy": kwargs.pop("copy", False),
+    }
     kwargs["backend_kwargs"] = backend_kwargs
     if kwargs.get("concat_dim", False):
         kwargs["combine"] = "nested"
