@@ -784,21 +784,54 @@ class TestGdal:
     @requires_gdal
     def test_reproject_raster_dataset(self, gdal_data):
         georef.reproject_raster_dataset(
-            gdal_data.ds, spacing=0.005, resample=gdal.GRA_Bilinear, align=True
+            gdal_data.ds, spacing=0.05, resample=gdal.GRA_Bilinear, align=True
         )
         georef.reproject_raster_dataset(
-            gdal_data.ds, size=(1000, 1000), resample=gdal.GRA_Bilinear, align=True
+            gdal_data.ds, size=(100, 100), resample=gdal.GRA_Bilinear, align=True
         )
-        with pytest.raises(NameError):
+        with pytest.raises(
+            NameError, match="Whether keyword 'spacing' or 'size' must be given"
+        ):
             georef.reproject_raster_dataset(gdal_data.ds)
         dst = georef.epsg_to_osr(25832)
         georef.reproject_raster_dataset(
             gdal_data.ds,
-            spacing=100.0,
+            spacing=1000.0,
             resample=gdal.GRA_Bilinear,
             align=True,
             projection_target=dst,
         )
+        with pytest.warns(
+            UserWarning, match="both ``spacing`` and ``size`` kwargs given"
+        ):
+            georef.reproject_raster_dataset(
+                gdal_data.ds,
+                spacing=1000.0,
+                size=200,
+                resample=gdal.GRA_Bilinear,
+                align=True,
+                projection_target=dst,
+            )
+        ds = gdal.GetDriverByName("MEM").CreateCopy("out", gdal_data.ds, 0)
+        ds.SetProjection("")
+        with pytest.raises(
+            ValueError, match="src_ds is missing projection information"
+        ):
+            georef.reproject_raster_dataset(
+                ds,
+                spacing=1000.0,
+                resample=gdal.GRA_Bilinear,
+                align=True,
+                projection_target=dst,
+            )
+        georef.reproject_raster_dataset(
+            ds,
+            spacing=1000.0,
+            resample=gdal.GRA_Bilinear,
+            align=True,
+            projection_source=gdal_data.proj,
+            projection_target=dst,
+        )
 
     @requires_gdal
     def test_create_raster_dataset(self, gdal_data):
@@ -881,11 +914,11 @@ class TestGdal:
     @requires_data
     @requires_secrets
     @requires_gdal
-    def test_get_raster_elevation(self, gdal_data):
+    def test_get_raster_elevation(self):
+        filename = "geo/bonn_new.tif"
+        geofile = util.get_wradlib_data_file(filename)
         # crop file using translate to keep download sizes minimal
-        gdal.Translate(
-            "/vsimem/clip.tif", gdal_data.geofile1, projWin=[5.5, 49.5, 5.6, 49.4]
-        )
+        gdal.Translate("/vsimem/clip.tif", geofile, projWin=[5.5, 49.5, 5.6, 49.4])
         ds = wradlib.io.open_raster("/vsimem/clip.tif")
         georef.get_raster_elevation(ds)
 
@@ -942,8 +975,8 @@ class TestGetGrids:
         scale = (1.0 + np.sin(np.radians(60.0))) / (1.0 + np.sin(np.radians(90.0)))
         dwd_string = (
             "+proj=stere +lat_0=90 +lat_ts=90 +lon_0=10 "
-            "+k={0:10.8f} +x_0=0 +y_0=0 +a=6370040 +b=6370040 "
-            "+to_meter=1000 +no_defs".format(scale)
+            f"+k={scale:10.8f} +x_0=0 +y_0=0 +a=6370040 +b=6370040 "
+            "+to_meter=1000 +no_defs"
         )
         proj_stereo = georef.proj4_to_osr(dwd_string)
 
@@ -996,8 +1029,8 @@ class TestGetGrids:
         assert pytest.approx(y) == -3971.7689758313813
         # Also test with trigonometric approach
         x, y = georef.get_radolan_coords(7.0, 53.0, trig=True)
-        assert x == -208.15159184860175
-        assert y == -3971.7689758313832
+        assert pytest.approx(x) == -208.15159184860175
+        assert pytest.approx(y) == -3971.7689758313832
 
     def test_xyz_to_spherical(self):
         xyz = np.array([[1000, 1000, 1000]])
@@ -1026,7 +1059,7 @@ class TestGetGrids:
     @requires_gdal
     def test_grid_reference_points(self, grid, origin, wgs):
         arr = list(georef.get_radolan_grid(grid[0], grid[1], wgs84=wgs)[0, 0])
-        assert pytest.approx(arr, origin[0])
+        assert pytest.approx(arr) == origin
 
 
 @pytest.fixture
@@ -1044,9 +1077,8 @@ def sat_data():
         a = wgs84.GetSemiMajor()
         b = wgs84.GetSemiMinor()
         rad = georef.proj4_to_osr(
-            (
-                "+proj=aeqd +lon_0={lon:f} " + "+lat_0={lat:f} +a={a:f} +b={b:f}" + ""
-            ).format(lon=pr_lon[68, 0], lat=pr_lat[68, 0], a=a, b=b)
+            f"+proj=aeqd +lon_0={pr_lon[68, 0]:f} +lat_0={pr_lat[68, 0]:f} "
+            f"+a={a:f} +b={b:f}"
         )
         pr_x, pr_y = georef.reproject(
             pr_lon, pr_lat, projection_source=wgs84, projection_target=rad
@@ -1272,14 +1304,18 @@ class TestVector:
     @requires_data
     @requires_gdal
     def test_get_vector_coordinates(self, vec_data):
-        filename = util.get_wradlib_data_file("shapefiles/agger/" "agger_merge.shp")
+        filename = util.get_wradlib_data_file("shapefiles/agger/agger_merge.shp")
+        proj_gk2 = osr.SpatialReference()
+        proj_gk2.ImportFromEPSG(31466)
         ds, layer = wradlib.io.open_vector(filename)
 
         # this also tests equality with `ogr_to_numpy`
-        x, attrs = georef.get_vector_coordinates(layer, key="FID")
+        x, attrs = georef.get_vector_coordinates(
+            layer, key="FID", source_srs=vec_data.proj
+        )
         assert attrs == list(range(13))
 
-        x, attrs = georef.get_vector_coordinates(layer)
+        x, attrs = georef.get_vector_coordinates(layer, source_srs=vec_data.proj)
         y = []
         layer.ResetReading()
         for i in range(layer.GetFeatureCount()):
@@ -1296,9 +1332,6 @@ class TestVector:
             layer, source_srs=vec_data.proj, dest_srs=vec_data.wgs84
         )
 
-        layer.ResetReading()
-        x, attrs = georef.get_vector_coordinates(layer, dest_srs=vec_data.wgs84)
-
     @requires_gdal
     def test_transform_geometry(self, vec_data):
         geom = georef.transform_geometry(vec_data.projobj, dest_srs=vec_data.wgs84)
