@@ -9,6 +9,7 @@ import subprocess
 import sys
 import tempfile
 import zlib
+from dataclasses import dataclass
 
 import deprecation
 import numpy as np
@@ -22,6 +23,7 @@ from . import (
     requires_dask,
     requires_data,
     requires_gdal,
+    requires_geos,
     requires_h5netcdf,
     requires_h5py,
     requires_netcdf,
@@ -330,7 +332,7 @@ class TestHDF5:
 
         command = "rm -rf test1.h5"
         subprocess.check_call(command, shell=True)
-        command = "h5copy -i {} -o test1.h5 -s CT -d CT".format(safnwcfile)
+        command = f"h5copy -i {safnwcfile} -o test1.h5 -s CT -d CT"
         subprocess.check_call(command, shell=True)
         with pytest.raises(KeyError):
             io.gdal.read_safnwc("test1.h5")
@@ -347,7 +349,7 @@ class TestHDF5:
         filename2 = "hdf5/IDR66_20141206_094829.vol.h5"
         gr2gpm_file = util.get_wradlib_data_file(filename2)
         gr_data = io.netcdf.read_generic_netcdf(gr2gpm_file)
-        dset = gr_data["dataset{0}".format(2)]
+        dset = gr_data["dataset2"]
         nray_gr = dset["where"]["nrays"]
         ngate_gr = dset["where"]["nbins"].astype("i4")
         elev_gr = dset["where"]["elangle"]
@@ -382,7 +384,7 @@ class TestHDF5:
         filename2 = "hdf5/IDR66_20141206_094829.vol.h5"
         gr2gpm_file = util.get_wradlib_data_file(filename2)
         gr_data = io.netcdf.read_generic_netcdf(gr2gpm_file)
-        dset = gr_data["dataset{0}".format(2)]
+        dset = gr_data["dataset2"]
         nray_gr = dset["where"]["nrays"]
         ngate_gr = dset["where"]["nbins"].astype("i4")
         elev_gr = dset["where"]["elangle"]
@@ -663,7 +665,7 @@ class TestRadolan:
         assert rw_file == rw_fid.name
         rw_fid.close()
 
-        command = "gunzip -k -f {}".format(rw_file)
+        command = f"gunzip -k -f {rw_file}"
         subprocess.check_call(command, shell=True)
 
         with io.radolan.get_radolan_filehandle(rw_file[:-3]) as rw_fid:
@@ -1279,7 +1281,11 @@ class TestRainbow:
         np.testing.assert_allclose(io.rainbow.map_rb_data(indata, 32), outdata32)
         flagdata = b"1"
         np.testing.assert_allclose(
-            io.rainbow.map_rb_data(flagdata, 1), [0, 0, 1, 1, 0, 0, 0, 1]
+            io.rainbow.map_rb_data(flagdata, 1, 8), [0, 0, 1, 1, 0, 0, 0, 1]
+        )
+        # added test for truncation
+        np.testing.assert_allclose(
+            io.rainbow.map_rb_data(flagdata, 1, 6), [0, 0, 1, 1, 0, 0]
         )
 
     def test_get_rb_blob_data(self):
@@ -1430,6 +1436,155 @@ class TestVector:
         io.gdal.open_vector(geofile, "ESRI Shapefile")
 
 
+@pytest.fixture
+def data_source():
+    @dataclass(init=False, repr=False, eq=False)
+    class Data:
+        # create synthetic box
+        box0 = np.array(
+            [
+                [2600000.0, 5630000.0],
+                [2600000.0, 5640000.0],
+                [2610000.0, 5640000.0],
+                [2610000.0, 5630000.0],
+                [2600000.0, 5630000.0],
+            ]
+        )
+
+        box1 = np.array(
+            [
+                [2700000.0, 5630000.0],
+                [2700000.0, 5640000.0],
+                [2710000.0, 5640000.0],
+                [2710000.0, 5630000.0],
+                [2700000.0, 5630000.0],
+            ]
+        )
+
+        data = np.array([box0, box1], dtype=object)
+
+        ds = io.VectorSource(data)
+
+        values1 = np.array([47.11, 47.11])
+        values2 = np.array([47.11, 15.08])
+
+    yield Data
+
+
+@requires_geos
+class TestVectorSource:
+    @requires_data
+    @requires_gdal
+    def test__check_src(self):
+        from osgeo import osr
+
+        proj_gk2 = osr.SpatialReference()
+        proj_gk2.ImportFromEPSG(31466)
+        filename = util.get_wradlib_data_file("shapefiles/agger/agger_merge.shp")
+        assert len(io.VectorSource(filename, srs=proj_gk2).data) == 13
+
+    @requires_gdal
+    def test_error(self):
+        with pytest.raises(ValueError):
+            filename = util.get_wradlib_data_file("shapefiles/agger/agger_merge.shp")
+            io.VectorSource(filename)
+        with pytest.raises(RuntimeError):
+            io.VectorSource("test_zonalstats.py")
+
+    @requires_gdal
+    def test_data(self, data_source):
+        np.testing.assert_almost_equal(data_source.ds.data, data_source.data)
+
+    @requires_gdal
+    def test__get_data(self, data_source):
+        ds = io.VectorSource(data_source.data)
+        np.testing.assert_almost_equal(ds._get_data(), data_source.data)
+
+    @requires_gdal
+    def test_get_data_by_idx(self, data_source):
+        ds = io.VectorSource(data_source.data)
+        np.testing.assert_almost_equal(ds.get_data_by_idx([0]), data_source.data[0:1])
+        np.testing.assert_almost_equal(ds.get_data_by_idx([1]), data_source.data[1:2])
+        np.testing.assert_almost_equal(ds.get_data_by_idx([0, 1]), data_source.data)
+
+    @requires_gdal
+    def test_get_data_by_att(self, data_source):
+        ds = io.VectorSource(data_source.data)
+        np.testing.assert_almost_equal(
+            ds.get_data_by_att("index", 0), data_source.data[0:1]
+        )
+        np.testing.assert_almost_equal(
+            ds.get_data_by_att("index", 1), data_source.data[1:2]
+        )
+
+    @requires_gdal
+    def test_get_data_by_geom(self, data_source):
+        ds = io.VectorSource(data_source.data)
+        lyr = ds.ds.GetLayer()
+        lyr.ResetReading()
+        lyr.SetSpatialFilter(None)
+        lyr.SetAttributeFilter(None)
+        for i, feature in enumerate(lyr):
+            geom = feature.GetGeometryRef()
+            np.testing.assert_almost_equal(
+                ds.get_data_by_geom(geom), data_source.data[i : i + 1]
+            )
+
+    @requires_gdal
+    def test_set_attribute(self, data_source):
+        ds = io.VectorSource(data_source.data)
+        ds.set_attribute("test", data_source.values1)
+        assert np.allclose(ds.get_attributes(["test"]), data_source.values1)
+        ds.set_attribute("test", data_source.values2)
+        assert np.allclose(ds.get_attributes(["test"]), data_source.values2)
+
+    @requires_gdal
+    def test_get_attributes(self, data_source):
+        ds = io.VectorSource(data_source.data)
+        ds.set_attribute("test", data_source.values2)
+        assert ds.get_attributes(["test"], filt=("index", 0)) == data_source.values2[0]
+        assert ds.get_attributes(["test"], filt=("index", 1)) == data_source.values2[1]
+
+    @requires_data
+    @requires_gdal
+    def test_get_geom_properties(self):
+        from osgeo import osr
+
+        proj = osr.SpatialReference()
+        proj.ImportFromEPSG(31466)
+        filename = util.get_wradlib_data_file("shapefiles/agger/" "agger_merge.shp")
+        test = io.VectorSource(filename, proj)
+        np.testing.assert_array_equal(
+            [[76722499.98474795]], test.get_geom_properties(["Area"], filt=("FID", 1))
+        )
+
+    @requires_gdal
+    def test_dump_vector(self, data_source):
+        ds = io.VectorSource(data_source.data)
+        ds.dump_vector(tempfile.NamedTemporaryFile(mode="w+b").name)
+
+    @requires_data
+    @requires_gdal
+    def test_dump_raster(self):
+        from osgeo import osr
+
+        proj = osr.SpatialReference()
+        proj.ImportFromEPSG(31466)
+        filename = util.get_wradlib_data_file("shapefiles/agger/" "agger_merge.shp")
+        test = io.VectorSource(filename, srs=proj)
+        test.dump_raster(
+            tempfile.NamedTemporaryFile(mode="w+b").name,
+            driver="netCDF",
+            pixel_size=100.0,
+        )
+        test.dump_raster(
+            tempfile.NamedTemporaryFile(mode="w+b").name,
+            driver="netCDF",
+            pixel_size=100.0,
+            attr="FID",
+        )
+
+
 class TestIris:
     @requires_data
     def test_open_iris(self, file_or_filelike):
@@ -1735,20 +1890,22 @@ class TestXarray:
     def test_iter(self):
         filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
         ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray.CfRadial(ncfile)
+        cf = io.xarray_depr.CfRadial(ncfile)
         assert len(cf) == cf.sweep
         assert len(cf) == 9
 
+    @deprecation.fail_if_not_removed
     @requires_data
     @requires_netcdf
     def test_del(self):
         filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
         ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray.CfRadial(ncfile)
+        cf = io.xarray_depr.CfRadial(ncfile)
         for k in list(cf):
             del cf[k]
         assert cf == {}
 
+    @deprecation.fail_if_not_removed
     @requires_data
     @requires_netcdf
     def test_read_cfradial(self):
@@ -1768,7 +1925,7 @@ class TestXarray:
         )
         filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
         ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray.CfRadial(ncfile)
+        cf = io.xarray_depr.CfRadial(ncfile)
         np.testing.assert_array_almost_equal(
             cf.root.sweep_fixed_angle.values, fixed_angles
         )
@@ -1786,22 +1943,24 @@ class TestXarray:
 
         assert repr(cf) == repr(cf._sweeps)
 
+    @deprecation.fail_if_not_removed
     @requires_data
     @requires_netcdf
     def test_read_odim(self):
         fixed_angles = np.array([0.3, 0.9, 1.8, 3.3, 6.0])
         filename = "hdf5/20130429043000.rad.bewid.pvol.dbzh.scan1.hdf"
         h5file = util.get_wradlib_data_file(filename)
-        cf = io.xarray.OdimH5(h5file)
+        cf = io.xarray_depr.OdimH5(h5file)
         np.testing.assert_array_almost_equal(
             cf.root.sweep_fixed_angle.values, fixed_angles
         )
         filename = "hdf5/knmi_polar_volume.h5"
         h5file = util.get_wradlib_data_file(filename)
-        cf = io.xarray.OdimH5(h5file)
+        cf = io.xarray_depr.OdimH5(h5file)
         with pytest.raises(AttributeError):
-            cf = io.xarray.OdimH5(h5file, flavour="None")
+            cf = io.xarray_depr.OdimH5(h5file, flavour="None")
 
+    @deprecation.fail_if_not_removed
     @requires_data
     @requires_netcdf
     @requires_h5py
@@ -1810,62 +1969,65 @@ class TestXarray:
         filename = "hdf5/2014-08-10--182000.ppi.mvol"
         h5file = util.get_wradlib_data_file(filename)
         with pytest.raises(AttributeError):
-            io.xarray.OdimH5(h5file)
-        cf = io.xarray.OdimH5(h5file, flavour="GAMIC")
+            io.xarray_depr.OdimH5(h5file)
+        cf = io.xarray_depr.OdimH5(h5file, flavour="GAMIC")
         assert str(cf.root.time_coverage_start.values) == time_cov[0]
         assert str(cf.root.time_coverage_end.values) == time_cov[1]
 
         filename = "hdf5/2014-06-09--185000.rhi.mvol"
         h5file = util.get_wradlib_data_file(filename)
-        cf = io.xarray.OdimH5(h5file, flavour="GAMIC")
-        cf = io.xarray.OdimH5(h5file, flavour="GAMIC", strict=False)
+        cf = io.xarray_depr.OdimH5(h5file, flavour="GAMIC")
+        cf = io.xarray_depr.OdimH5(h5file, flavour="GAMIC", strict=False)
 
+    @deprecation.fail_if_not_removed
     @requires_data
     @requires_netcdf
     @requires_h5py
     def test_odim_roundtrip(self):
         filename = "hdf5/20130429043000.rad.bewid.pvol.dbzh.scan1.hdf"
         odimfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray.OdimH5(odimfile)
+        cf = io.xarray_depr.OdimH5(odimfile)
         tmp = tempfile.NamedTemporaryFile(mode="w+b").name
         cf.to_odim(tmp)
-        cf2 = io.xarray.OdimH5(tmp)
+        cf2 = io.xarray_depr.OdimH5(tmp)
         xr.testing.assert_equal(cf.root, cf2.root)
         for i in range(1, 6):
-            key = "sweep_{}".format(i)
+            key = f"sweep_{i}"
             xr.testing.assert_equal(cf[key], cf2[key])
         # test write after del, file lockage
         del cf2
         # this currently breaks on CI, maybe the above `del` does not work correctly
         # cf.to_odim(tmp)
 
+    @deprecation.fail_if_not_removed
     @requires_data
     @requires_netcdf
     def test_cfradial_roundtrip(self):
         filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
         ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray.CfRadial(ncfile)
+        cf = io.xarray_depr.CfRadial(ncfile)
         tmp = tempfile.NamedTemporaryFile(mode="w+b").name
         cf.to_cfradial2(tmp)
-        cf2 = io.xarray.CfRadial(tmp)
+        cf2 = io.xarray_depr.CfRadial(tmp)
         xr.testing.assert_equal(cf.root, cf2.root)
         for i in range(1, 10):
-            key = "sweep_{}".format(i)
+            key = f"sweep_{i}"
             xr.testing.assert_equal(cf[key], cf2[key])
         # test write after del, file lockage
         del cf2
         cf.to_cfradial2(tmp)
 
+    @deprecation.fail_if_not_removed
     @requires_data
     @requires_netcdf
     @requires_h5py
     def test_cfradial_odim_roundtrip(self):
         filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
         ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray.CfRadial(ncfile)
+        cf = io.xarray_depr.CfRadial(ncfile)
         tmp = tempfile.NamedTemporaryFile(mode="w+b").name
         cf.to_odim(tmp)
-        cf2 = io.xarray.OdimH5(tmp)
+        cf2 = io.xarray_depr.OdimH5(tmp)
         xr.testing.assert_allclose(
             cf.root.sweep_fixed_angle, cf2.root.sweep_fixed_angle
         )
@@ -1880,88 +2042,95 @@ class TestXarray:
 
         tmp1 = tempfile.NamedTemporaryFile(mode="w+b").name
         cf2.to_cfradial2(tmp1)
-        cf3 = io.xarray.CfRadial(tmp1)
+        cf3 = io.xarray_depr.CfRadial(tmp1)
         xr.testing.assert_allclose(
             cf.root.time_coverage_start, cf3.root.time_coverage_start
         )
 
+    @deprecation.fail_if_not_removed
     @requires_data
     @requires_netcdf
     @requires_gdal
     def test_georeference(self):
         filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
         ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray.CfRadial(ncfile, georef=True)
+        cf = io.xarray_depr.CfRadial(ncfile, georef=True)
         tmp = tempfile.NamedTemporaryFile(mode="w+b").name
         cf.to_cfradial2(tmp)
-        cf2 = io.xarray.CfRadial(tmp, georef=True)
+        cf2 = io.xarray_depr.CfRadial(tmp, georef=True)
         swp1 = cf["sweep_1"].copy()
         cf["sweep_1"] = cf["sweep_1"].drop_vars(["x", "y", "z", "gr", "rays", "bins"])
         cf.georeference()
         xr.testing.assert_equal(swp1, cf["sweep_1"])
         xr.testing.assert_equal(swp1, cf2["sweep_1"])
 
+    @deprecation.fail_if_not_removed
     @requires_data
     @requires_netcdf
     def test_root_key_warnings(self):
         filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
         ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray.CfRadial(ncfile)
+        cf = io.xarray_depr.CfRadial(ncfile)
         with pytest.warns(DeprecationWarning):
             cf["root"]
 
+    @deprecation.fail_if_not_removed
     @requires_data
     @requires_netcdf
     @requires_h5py
     def test_to_odim_warning(self):
         filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
         ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray.CfRadial(ncfile)
+        cf = io.xarray_depr.CfRadial(ncfile)
         cf.root = None
         with pytest.warns(UserWarning):
             cf.to_odim("test.h5")
 
+    @deprecation.fail_if_not_removed
     @requires_data
     @requires_netcdf
     def test_to_cfradial2_warning(self):
         filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
         ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray.CfRadial(ncfile)
+        cf = io.xarray_depr.CfRadial(ncfile)
         cf.root = None
         with pytest.warns(UserWarning):
             cf.to_cfradial2("test.nc")
 
+    @deprecation.fail_if_not_removed
     @requires_data
     @requires_netcdf
     def test_setitem_warning(self):
         filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
         ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray.CfRadial(ncfile)
+        cf = io.xarray_depr.CfRadial(ncfile)
         with pytest.warns(UserWarning):
             cf["test"] = None
 
+    @deprecation.fail_if_not_removed
     @requires_data
     @requires_netcdf
     def test_odim_errors(self):
         filename = "netcdf/edge_netcdf.nc"
         ncfile = util.get_wradlib_data_file(filename)
         with pytest.raises(TypeError):
-            io.xarray.OdimH5(ncfile)
+            io.xarray_depr.OdimH5(ncfile)
 
         filename = "netcdf/example_cfradial_ppi.nc"
         ncfile = util.get_wradlib_data_file(filename)
         with pytest.raises(AttributeError):
-            io.xarray.OdimH5(ncfile)
+            io.xarray_depr.OdimH5(ncfile)
 
+    @deprecation.fail_if_not_removed
     @requires_data
     @requires_netcdf
     def test_netcdf4_errors(self):
         filename = "hdf5/2014-08-10--182000.ppi.mvol"
         h5file = util.get_wradlib_data_file(filename)
         with pytest.raises(AttributeError):
-            io.xarray.CfRadial(h5file, flavour="Cf/Radial3")
+            io.xarray_depr.CfRadial(h5file, flavour="Cf/Radial3")
         with pytest.raises(AttributeError):
-            io.xarray.CfRadial(h5file)
+            io.xarray_depr.CfRadial(h5file)
 
 
 class TestDem:
@@ -1971,7 +2140,7 @@ class TestDem:
     @pytest.mark.xfail(strict=False)
     def test_get_srtm(self):
         targets = ["N51W001", "N51E000", "N51E001", "N52W001", "N52E000", "N52E001"]
-        targets = ["%s.SRTMGL3.hgt.zip" % (f) for f in targets]
+        targets = [f"{f}.SRTMGL3.hgt.zip" for f in targets]
 
         extent = [-0.3, 1.5, 51.4, 52.5]
         datasets = io.dem.get_srtm(extent, merge=False)
@@ -1979,7 +2148,7 @@ class TestDem:
         assert targets == filelist
 
         targets = ["S02E015", "S02E016", "S01E015", "S01E016", "N00E015", "N00E016"]
-        targets = ["%s.SRTMGL3.hgt.zip" % (f) for f in targets]
+        targets = [f"{f}.SRTMGL3.hgt.zip" for f in targets]
 
         extent = [15.3, 16.6, -1.4, 0.4]
         datasets = io.dem.get_srtm(extent, merge=False)
