@@ -53,7 +53,7 @@ def maximum_intensity_projection(*args, **kwargs):
     return polar.maximum_intensity_projection(*args, **kwargs)
 
 
-class OptionalModuleStub(object):
+class OptionalModuleStub:
     """Stub class for optional imports.
 
     Objects of this class are instantiated when optional modules are not
@@ -71,14 +71,12 @@ class OptionalModuleStub(object):
             "installation.html#optional-dependencies"
         )
         raise AttributeError(
-            'Module "{0}" is not installed.\n\n'
+            f"Module '{self.name}' is not installed.\n\n"
             "You tried to access function/module/attribute "
-            '"{1}"\nfrom module "{0}".\nThis module is '
+            f"'{name}'\nfrom module '{self.name}'.\nThis module is "
             "optional right now in wradlib.\nYou need to "
             "separately install this dependency.\n"
-            "Please refer to {2}\nfor further instructions.".format(
-                self.name, name, link
-            )
+            f"Please refer to {link}\nfor further instructions."
         )
 
 
@@ -105,7 +103,7 @@ def import_optional(module):
     Trying to import a module that exists makes the module available as normal.
     You can even use an alias. You cannot use the '*' notation, or import only
     select functions, but you can simulate most of the standard import syntax
-    behavior
+    behavior.
     >>> m = import_optional('math')
     >>> m.log10(100)
     2.0
@@ -116,10 +114,10 @@ def import_optional(module):
     >>> m.log10(100)  #doctest: +ELLIPSIS
     Traceback (most recent call last):
     ...
-    AttributeError: Module "nonexistentmodule" is not installed.
+    AttributeError: Module 'nonexistentmodule' is not installed.
     <BLANKLINE>
-    You tried to access function/module/attribute "log10"
-    from module "nonexistentmodule".
+    You tried to access function/module/attribute 'log10'
+    from module 'nonexistentmodule'.
     This module is optional right now in wradlib.
     You need to separately install this dependency.
     Please refer to https://docs.wradlib.org/en/stable/installation.html#optional-dependencies
@@ -337,7 +335,7 @@ def filter_window_polar(img, wsize, fun, rscale, random=False):
     """
     ascale = 2 * np.pi / img.shape[0]
     data_filtered = np.empty(img.shape, dtype=img.dtype)
-    fun = getattr(ndimage.filters, "%s_filter1d" % fun)
+    fun = getattr(ndimage.filters, f"{fun}_filter1d")
     nbins = img.shape[-1]
     ranges = np.arange(nbins) * rscale + rscale / 2
     asize = ranges * ascale
@@ -375,7 +373,7 @@ def prob_round(x, prec=0):
     prec : int
         precision
     """
-    fixup = np.sign(x) * 10 ** prec
+    fixup = np.sign(x) * 10**prec
     x *= fixup
     intx = x.astype(int)
     round_func = intx + np.random.binomial(1, x - intx)
@@ -404,7 +402,7 @@ def filter_window_cartesian(img, wsize, fun, scale, **kwargs):
         Array with the same shape as `img`, containing the filter's results.
 
     """
-    fun = getattr(ndimage.filters, "%s_filter" % fun)
+    fun = getattr(ndimage.filters, f"{fun}_filter")
     size = np.fix(wsize / scale + 0.5).astype(int)
     data_filtered = fun(img, size, **kwargs)
     return data_filtered
@@ -594,18 +592,14 @@ def get_wradlib_data_path():
     if wrl_data_path is None:
         raise EnvironmentError("'WRADLIB_DATA' environment variable not set")
     if not os.path.isdir(wrl_data_path):
-        raise EnvironmentError(
-            "'WRADLIB_DATA' path '{0}' " "does not exist".format(wrl_data_path)
-        )
+        raise EnvironmentError(f"'WRADLIB_DATA' path '{wrl_data_path}' does not exist")
     return wrl_data_path
 
 
 def get_wradlib_data_file(relfile):
     data_file = os.path.abspath(os.path.join(get_wradlib_data_path(), relfile))
     if not os.path.exists(data_file):
-        raise EnvironmentError(
-            "WRADLIB_DATA file '{0}' " "does not exist".format(data_file)
-        )
+        raise EnvironmentError(f"WRADLIB_DATA file '{data_file}' does not exist")
     return data_file
 
 
@@ -632,7 +626,7 @@ def calculate_polynomial(data, w):
     """
     poly = np.zeros_like(data)
     for i, c in enumerate(w):
-        poly += c * data ** i
+        poly += c * data**i
     return poly
 
 
